@@ -1,9 +1,7 @@
-from __future__ import print_function, division
-
-import os
-from os import scandir
+from os import DirEntry, lstat, scandir, stat
+from os import name as os_name
+from os import path as os_path
 from pathlib import Path
-from posix import DirEntry
 
 import attr
 
@@ -11,15 +9,15 @@ from .compat import fspath
 
 
 @attr.s(slots=True)  # TODO consider make frozen.
-class RecursionPath(object):
+class RecursionPath:
     """Caches the properties of directory entries including the path relative to the
     root directory for recursion.
 
     NOTE: this class is normally only ever instantiated by the `scantree` function.
 
-    The class provides the `DirEntry` interface (found in the external `scandir`
-    module in Python < 3.5 or builtin `posix` module in Python >= 3.5).
+    The class provides the os-portable `DirEntry` interface.
     """
+
     root = attr.ib()
     relative = attr.ib()
     real = attr.ib()
@@ -34,9 +32,9 @@ class RecursionPath(object):
             dir_entry = DirEntryReplacement.from_path(directory)
         return cls(
             root=dir_entry.path,
-            relative='',
-            real=os.path.realpath(dir_entry.path),
-            dir_entry=dir_entry
+            relative="",
+            real=os_path.realpath(dir_entry.path),
+            dir_entry=dir_entry,
         )
 
     def scandir(self):
@@ -48,22 +46,22 @@ class RecursionPath(object):
         return (self._join(dir_entry) for dir_entry in scandir(self.absolute))
 
     def _join(self, dir_entry):
-        relative = os.path.join(self.relative, dir_entry.name)
-        real = os.path.join(self.real, dir_entry.name)
+        relative = os_path.join(self.relative, dir_entry.name)
+        real = os_path.join(self.real, dir_entry.name)
         if dir_entry.is_symlink():
             # For large number of files/directories it improves performance
-            # significantly to only call `os.realpath` when we are actually
+            # significantly to only call `os_path.realpath` when we are actually
             # encountering a symlink.
-            real = os.path.realpath(real)
+            real = os_path.realpath(real)
 
         return attr.evolve(self, relative=relative, real=real, dir_entry=dir_entry)
 
     @property
     def absolute(self):
         """The absolute path to this entry"""
-        if self.relative == '':
+        if self.relative == "":
             return self.root  # don't join in this case as that appends trailing '/'
-        return os.path.join(self.root, self.relative)
+        return os_path.join(self.root, self.relative)
 
     @property
     def path(self):
@@ -107,7 +105,7 @@ class RecursionPath(object):
             self.root,
             self.relative,
             self.real,
-            DirEntryReplacement.from_dir_entry(self._dir_entry)
+            DirEntryReplacement.from_dir_entry(self._dir_entry),
         )
 
     @staticmethod
@@ -122,14 +120,15 @@ RecursionPath.__setstate__ = RecursionPath._setstate
 
 
 @attr.s(slots=True, eq=False, order=False)
-class DirEntryReplacement(object):
-    """Pure python implementation of the `DirEntry` interface (found in the external
-    `scandir` module in Python < 3.5 or builtin `posix` module in Python >= 3.5)
+class DirEntryReplacement:
+    """Pure python implementation of the os-portable `DirEntry` interface.
+
 
     A `DirEntry` cannot be instantiated directly (only returned from a call to
     `scandir`). This class offers a drop in replacement. Useful in testing and for
     representing the root directory for `scantree` implementation.
     """
+
     path = attr.ib(converter=fspath)
     name = attr.ib()
     _is_dir = attr.ib(init=False, default=None)
@@ -141,11 +140,11 @@ class DirEntryReplacement(object):
     @classmethod
     def from_path(cls, path):
         path = fspath(path)
-        if not os.path.exists(path):
-            raise IOError('{} does not exist'.format(path))
-        basename = os.path.basename(path)
-        if basename in ['', '.', '..']:
-            name = os.path.basename(os.path.realpath(path))
+        if not os_path.exists(path):
+            raise OSError(f"{path} does not exist")
+        basename = os_path.basename(path)
+        if basename in ["", ".", ".."]:
+            name = os_path.basename(os_path.realpath(path))
         else:
             name = basename
         return cls(path, name)
@@ -156,7 +155,7 @@ class DirEntryReplacement(object):
 
     def is_dir(self, follow_symlinks=True):
         if self._is_dir is None:
-            self._is_dir = os.path.isdir(self.path)
+            self._is_dir = os_path.isdir(self.path)
         if follow_symlinks:
             return self._is_dir
         else:
@@ -164,7 +163,7 @@ class DirEntryReplacement(object):
 
     def is_file(self, follow_symlinks=True):
         if self._is_file is None:
-            self._is_file = os.path.isfile(self.path)
+            self._is_file = os_path.isfile(self.path)
         if follow_symlinks:
             return self._is_file
         else:
@@ -172,17 +171,17 @@ class DirEntryReplacement(object):
 
     def is_symlink(self):
         if self._is_symlink is None:
-            self._is_symlink = os.path.islink(self.path)
+            self._is_symlink = os_path.islink(self.path)
         return self._is_symlink
 
     def stat(self, follow_symlinks=True):
         if follow_symlinks:
             if self._stat_sym is None:
-                self._stat_sym = os.stat(self.path)
+                self._stat_sym = stat(self.path)
             return self._stat_sym
 
         if self._stat_nosym is None:
-            self._stat_nosym = os.lstat(self.path)
+            self._stat_nosym = lstat(self.path)
         return self._stat_nosym
 
     def inode(self):
@@ -195,16 +194,23 @@ class DirEntryReplacement(object):
             return False
         if not self.name == other.name:
             return False
-        for method, kwargs in [
-            ('is_dir', {'follow_symlinks': True}),
-            ('is_dir', {'follow_symlinks': False}),
-            ('is_file', {'follow_symlinks': True}),
-            ('is_file', {'follow_symlinks': False}),
-            ('is_symlink', {}),
-            ('stat', {'follow_symlinks': True}),
-            ('stat', {'follow_symlinks': False}),
-            ('inode', {})
-        ]:
+        methods = [
+            ("is_dir", {"follow_symlinks": True}),
+            ("is_dir", {"follow_symlinks": False}),
+            ("is_file", {"follow_symlinks": True}),
+            ("is_file", {"follow_symlinks": False}),
+            ("is_symlink", {}),
+        ]
+        if os_name != "nt":  # pragma: no cover
+            methods.extend(
+                [
+                    ("stat", {"follow_symlinks": True}),
+                    ("stat", {"follow_symlinks": False}),
+                    ("inode", {}),
+                ]
+            )
+
+        for method, kwargs in methods:
             this_res = getattr(self, method)(**kwargs)
             other_res = getattr(other, method)(**kwargs)
             if not this_res == other_res:
